# Introduction

CNCF participates in and organises a variety of mentoring programs. CNCF is a great place to spend time learning, coding, documenting, participating, and contributing. We look forward to receiving your application to become a mentor, along with your innovative project ideas!

In this guide, we aim to provide you with valuable insights into the importance of being a mentor, the steps to becoming one, and what you can anticipate in your role as a mentor. Additionally, we offer a range of resources to support you in getting started and maximising your mentoring experience.

## Why become a mentor?

Mentoring allows you to give back to the community and support others in their learning journey, and presents an opportunity for personal and professional growth. Mentoring enables you to acquire new skills and enhance your existing knowledge. It is a profoundly fulfilling experience that fosters personal and professional development.

Moreover, mentoring serves as an effective means to attract new contributors to your project and community while simultaneously improving their skills. It creates a positive cycle of mentorship and collaboration that benefits both the mentor and the mentee.

Linux Foundation has a very good article titled "Why to Become a Mentor" [document](https://docs.linuxfoundation.org/lfx/mentorship/mentor-guide/getting-started/why-to-become-a-mentor) which provides valuable insights into the numerous benefits of being a mentor. This document shares compelling success stories and offers further information to illustrate why mentoring is such a rewarding experience.

## Expectations from Mentors

Mentors are expected to:
- Generate project ideas for potential mentees before the program starts
- Evaluate mentees and proposals submitted by mentees for acceptance into the program
- Be available to answer questions and provide guidance to mentees
- Help mentees get involved in the community, including code reviews, documentation, and other contributions
- Help mentees learn some soft skills, such as communication, teamwork, time management, and community mechanics
- Provide feedback on the mentee's work

Every mentorship program CNCF participates in or organise is a full-time mentorship program. While the mentees are expected to spend 30-40 hours per week on the programs, mentors are expected to spend 3-6 hours per week per mentee. This includes time spent on project ideas, reviewing proposals, answering questions, and providing feedback. Each project, mentee, and mentor is unique in their own way, and the time commitment may vary. Collaborating with fellow mentors can assist in distributing the time commitment.

In general, anyone can become a mentor; however, we do require that you possess substantial experience with the project you are mentoring for and familiarity with the community and its processes. Additionally, you should be capable of answering questions and providing guidance to the mentees.

## Non-duties of Mentors

The following are not within the scope of the mentor's duties:
- Do the work for the mentees
- Be available 24/7
- Find a job for the mentees
- Push mentees to do the project tasks

## How to become a mentor?

Short answer: Generate a project proposal that is suitable for a mentorship and present it to the CNCF mentoring group by submitting a PR!

Long answer:
1. **Watch out for the announcements**: CNCF mentoring programs are announced on CNCF Twitter ([@CloudNativeFdn](https://twitter.com/CloudNativeFdn)) and CNCF Slack ([#mentoring](https://cloud-native.slack.com/archives/CGPK98JNQ)). You can also watch the announcements on the CNCF mentoring repository.
2. **Find a project idea**: Either come up with a new mentorship project idea or find an existing mentorship project idea that you would like to mentor for.
   The definition of a good project idea varies from program to program. Different mentorship programs and project initiatives have their own unique focuses and areas of emphasis. For instance, some projects place a greater emphasis on coding and software development, while others prioritise documentation and technical writing. The specific goals and objectives of each program may vary, but generally, they strive to provide valuable learning experiences and support to participants in their respective fields.
3. **Submit your project idea**: Submit your project idea to the [CNCF mentoring repository](https://github.com/cncf/mentoring). You can use the [project idea template](https://github.com/cncf/mentoring/blob/main/PROJECT_IDEA_TEMPLATE.md). Information on how to submit your project idea will be provided in the program announcement that will be sent out.
4. **Review mentee profiles and proposals**: Once the mentee profiles and proposals are submitted for your project idea, you will  have the opportunity to review them. Program administrators will provide you with more information on how to review the proposals and the main criteria for acceptance.
5. **Mentor the mentees**: Once the mentees are accepted into the program, you will be able to start mentoring them!

While the processes may vary from program to program, you will receive detailed instructions from the program administrators at each step, including a timeline. This ensures that you are well informed about what needs to be done and how to proceed throughout the program!

## Programs

For the up-to-date list of programs, please check the [CNCF mentoring repository](https://github.com/cncf/mentoring).

## Example mentoring timeline

* GSoC at CNCF 2023 is [announced](https://github.com/cncf/mentoring/discussions/848)
  * Mentors send their project idea PRs ([example](https://github.com/cncf/mentoring/pull/810))
* Mentee applications start ([announcement](https://github.com/cncf/mentoring/discussions/892))
  * Mentee candidates interact with the community and the mentors
  * Mentee candidates submit their proposals to the GSoC platform
*  Mentee applications close ([announcement](https://github.com/cncf/mentoring/discussions/918))
  * Mentors review the proposals and provide feedback
* Accepted mentees are [announced](https://github.com/cncf/mentoring/discussions/954)
  * Mentees bond with the community and the mentors
  * Mentors and mentees start working on their projects
* TBA: (we're in the middle of the program)

## Success Stories

TBD

## Best Practices

### Attracting Mentees

To attract mentees to your project idea, we recommend the following best practices:

- It is crucial that you have a well-defined project idea that is suitable for the mentorship program you are aiming to participate in.
- Submit your project idea early to give mentee candidates enough time to learn more about the project and interact with the community.
- Be available to answer questions when candidates ask questions about your project idea.

### Reviewing Mentee Applications and Proposals

To make the mentoring experience pleasant for you and for your mentee:

- Do not accept "just good enough" applications and proposals. Look for enthusiastic candidates with high quality proposals.
- Only accept as many mentees as you can handle. If you are unsure how many mentees you can handle, ask the program administrators.
- Set your expectations right in the project idea. You would want to avoid being in a situation where you and the mentee have mismatched expectations.
- Provide feedback to the candidates and help them improve their proposals. This will help you and your mentee in the long run.

### Mentoring Mentees

To make the most of your mentoring experience, we recommend the following best practices.

Before the mentorship begins:

- Start by reading the great resources in the [Mentor Resources](#mentor-resources) section.
- Introduce your mentee to the community and help them get familiar with the community processes.
- Ask your mentee to submit their work early and often and ask them to request community feedback.

During the mentorship:

- Be available for the mentee! This is the most important thing you can do for your mentee and will be the most rewarding.
- Encourage your mentee to interact with the community, and not just with you. While you will be the main person responsible for supporting the mentee’s work. A mentee interacting with the community will help to share your load. However, mentees may not have the confidence or experience to have this interaction and may need guidance from you.

After the mentorship:

- Look for opportunities to retain the mentee in the community after the program ends. This can be done by helping them find a new project to work on.
- Share your mentoring experience with your community and the broader open source community by collaborating on writing a blog post, delivering a joint talk, or creating  a demo together. Such efforts will contribute to your personal growth and help your community attract more mentees in the future.

## Support

Mentors have a direct line to us!

If you have any questions, please contact the CNCF mentoring group on [CNCF Slack](https://cloud-native.slack.com/archives/CGPK98JNQ) or on [CNCF Mentoring repository discussions](https://github.com/cncf/mentoring/discussions). We are happy to help you mentor your mentees!

## Mentor Resources

The Linux Foundation’s "What Makes a Good Mentor" [document](https://docs.linuxfoundation.org/lfx/mentorship/mentor-guide/getting-started/what-makes-a-good-mentor) is very useful. We encourage you to read it, regardless of the program you are participating in.

### Google Summer of Code

In addition to Google Summer of Code [official documentation](https://summerofcode.withgoogle.com/help), Google provides a lot of resources targeting mentors. We recommend you to check out the following resources:

- [GSoC Mentor Guide](https://google.github.io/gsocguides/mentor/)
- [GSoC FAQ for Mentors](https://developers.google.com/open-source/gsoc/faq#mentorsorganization_administrators)
- [GSoC Mentor Responsibilities](https://developers.google.com/open-source/gsoc/help/responsibilities#mentor_responsibilities)


### LFX Mentorship

LFX Mentorship [official documentation](https://docs.linuxfoundation.org/lfx/mentorship) has specific information for mentors. We encourage you to check out the following documents:

- [LFX Mentorship - Mentor Information](https://docs.linuxfoundation.org/lfx/mentorship/mentors)
- [LFX Mentorship - Mentor Guide](https://docs.linuxfoundation.org/lfx/mentorship/mentor-guide)

### Outreachy

Outreachy's [mentor CFP page](https://www.outreachy.org/communities/cfp/) has all the information specific to mentors.
